function flux=FluxFromConc(dconc,mnet)
% To obtain fluxes from concentration data
% INPUTS:
% - conc: concentratin data
% - mnet: metabolic network cell array from efmtool
% OUTPUTS:
% - flux data matrix (time points x fluxes)

% Matrix reshaping based on reversible reactions
S_orig=mnet.stoich;
[dcn,dcm]=size(dconc); %dconc = time points x differential concentrations
[Sn_orig,Sm_orig]=size(S_orig); %S = metabolites x reactions
reversible=find(mnet.reactionLowerBounds<0);
S=[S_orig -S_orig(:,reversible)];
[Sn,Sm]=size(S); %S = metabolites x reactions
dconc_vec=reshape(dconc',dcn*dcm,1);
S_rep=zeros(Sn*dcn,Sm*dcn);
for i=1:dcn
    for j=1:Sm
        S_rep((i-1)*Sn+1:i*Sn,(j-1)*dcn+i)=S(:,j);
    end
end

% Optimization problem definition.
h=eye(dcn);
h(1,:)=-ones(1,dcn);
h(:,1)=-ones(dcn,1);
h(1,1)=dcn;
hs='h';
for i=2:Sm
    hs=[hs ',h'];
end
eval(['H=blkdiag(' hs ');'])
f=zeros(dcn*Sm,1);
Aeq=S_rep;
beq=dconc_vec;
lb=zeros(dcn*Sm,1);
x0=lsqnonneg(Aeq,beq);
ub=Inf(dcn*Sm,1);

% Solve optimization problem
options.MaxIter=20000;
[x,fval,exitflag,output,lambda] = quadprog(H,f,[],[],Aeq,beq,lb,ub,[],options);
xnew=reshape(x,dcn,Sm);
flux=xnew;
for i=1:length(reversible)
    flux(:,reversible(i))=xnew(:,reversible(i))-xnew(:,i+Sm_orig);
end
flux=flux(:,1:Sm_orig);
