function [Xrec,a2]=NNLS(X,P)
% dynamic elementary mode analysis fit for dynEMR-DA model
% INPUTS:
% - X: 2D flux data set (experiments*time points x fluxes)
% - P: EM to be tested
% OUTPUT:
% - Xrec: X data reconstructed with the EM tested
% - a2: coefficients matrix multiplying the EM to reconstruct data 
% (experiments*time points x fluxes)

[xm,xn]=size(X);
[xn,en]=size(P);

% First section of dynEMA model (see equation 7 in manuscript)
x=reshape(X',xm*xn,1);
z=kron(kron(eye(xm),ones(1,en)),eye(xn));
d=diag(reshape(kron(ones(xm,1),P')',xm*xn*en,1));
B=z*d;

% Second section dynEMA model (see equation 7 in manuscript)
a1_aux=reshape(kron(ones(xm,1),P')',xm*xn*en,1);
a1=zeros(length(x),1);
a1(a1_aux>0)=x(a1_aux>0)./a1_aux(a1_aux>0);
a1(a1_aux<0)=x(a1_aux<0)./a1_aux(a1_aux<0);
a1(a1<0)=0;

% Compute reconstruction of X and reshape coefficients for output
Xrec=B*a1;
Xrec=reshape(Xrec',size(P,1),size(X,1))';
a2=reshape(a1,xn,en*xm)';