function [res]=dynEMRDA(flux3D,Y,EM,ncomp)
% dynamic elementary mode regression discriminant analysis function
% INPUTS:
% - flux3D: flux data (experiments x fluxes x time points)
% - discriminant variable (1s and 0s for the two groups)
% OUTPUTS:
% - res: array with as many rows as EMs, containing predictied true 1s, false 1s, 
% true 0s and false 0s. All experiments are correctly classified for a
% dynEM when its row is [total number of 1s, 0, total number of 0s, 0]

% Reshape data to have the flux in 2D and 3D
[m,n,p]=size(flux3D);
flux2D=[];
for i=1:size(flux3D,1)
    flux2D=[flux2D;reshape(flux3D(i,:,:),n,p)'];
end

for k=1:size(EM,2)
    flag=0;
    display(['Computing model with dynEM ', int2str(k),' from a total of ',int2str(size(EM,2))])
    
    % dynEMR-DA model projection
    [Xrec,a2]=NNLS(flux2D,EM(:,k));
    if nnz(max(a2))<nnz(EM(:,k))
        % A flag is raised when at least one variable is not used in the
        % dynEM, which implies it is NOT a dynEM
        flag=1;
    end
    
    % Format data for NPLS-DA
    vec=ceil(abs((EM(:,[k])'./max(max(abs(EM(:,k))))))).*[1:size(EM,1)];
    vec=sort(vec,'ascend');
    vec=vec(length(vec)-nnz(vec)+1:length(vec));
    Xrec_partial_aux=Xrec(:,vec);
    clear Xrec_partial
    for l=1:m
        Xrec_partial(l,:,:)=Xrec_partial_aux((l-1)*p+1:l*p,:)';
    end
    
    % Preprocess data and calculate NPLS-DA model
    [Xrec_partial,Means,Scales]=nprocess(Xrec_partial,[0 0 0],[0 0 1]);
    [Xfactors,Yfactors,Core,BB,ypred,ssx,ssy] = npls(Xrec_partial,Y,ncomp,1);
    [T,Wj,Wk]=fac2let(Xfactors);
    
    % Check predictions of the model
    [ypred,T,ssX,Xres]=npred(Xrec_partial,ncomp,Xfactors,Yfactors,Core,BB,1);
    ypredbin=ypred;
    ypredbin(ypred>=mean(Y))=1;
    ypredbin(ypred<mean(Y))=0;
    TP=sum(ypredbin(Y==1));
    FP=sum(ypredbin(Y==0));
    TN=sum(Y==0)-sum(ypredbin(Y==0));
    FN=sum(ypredbin(Y==1)==0);
    if flag==1
        res(k,:)=[-1 -1 -1 -1]; % indicates when dynEM was not valid
    else
        res(k,:)=[TP FP TN FN];
    end
end
